import time
import board
import displayio
import terminalio
from adafruit_display_text import label
import adafruit_ssd1327

displayio.release_displays()

try:
    i2c_bus = board.I2C()
except:
    print( "i2c bus failed to initialize" )
    i2c_bus = False

try:
    display_bus = displayio.I2CDisplay(i2c_bus, device_address=0x3D)
    display = adafruit_ssd1327.SSD1327(display_bus, width=128, height=128)
except:
    print( "display failed to initialize" )
    display = False

loop_count = 0
if display:
    display_group = displayio.Group()
    display.show( display_group )
    background_bitmap = displayio.Bitmap( 128, 128, 1 )
    background_palette = displayio.Palette(1)
    background_palette[0] = 0x888888  # Gray
    background_square = displayio.TileGrid( background_bitmap, pixel_shader=background_palette, x=0, y=0 )
    display_group.append(background_square)

    text = "STELLA"
    text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
    text_group = displayio.Group( scale=3, x=10, y=50 )
    text_group.append( text_area )
    display_group.append( text_group )


    text = "{}".format( loop_count )
    text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
    text_group = displayio.Group( scale=3, x=55, y=90 )
    text_group.append( text_area )
    display_group.append( text_group )
try:
    while True:
        time.sleep( 1 )
        loop_count += 1
        print( "loop count = {}".format( loop_count ))
        if display:
            text_area.text = str( loop_count )
finally:
        displayio.release_displays()
        print( "displayio displays released" )
        i2c_bus.deinit()
        print( "i2c_bus deinitialized" )
        print( " ---- end --- " )





