import time
import board
import displayio
import terminalio
from adafruit_display_text import label
import adafruit_ssd1327

import digitalio

try:
    onboard_LED = digitalio.DigitalInOut( board.LED )
    onboard_LED.direction = digitalio.Direction.OUTPUT
    print( "onboard_LED initialized" )
except:
    onboard_LED = False
    print( "onboard_LED not available" )

displayio.release_displays()

try:
    i2c_bus = board.I2C()
    print( "i2c bus initialized" )
except:
    print( "i2c bus failed to initialize" )
    i2c_bus = False

try:
    display_bus = displayio.I2CDisplay(i2c_bus, device_address=0x3D)
    display = adafruit_ssd1327.SSD1327(display_bus, width=128, height=128)
    print( "display initialized" )
except:
    print( "display failed to initialize" )
    display = False

loop_count = 0
if display:
    display_group = displayio.Group()
    display.show( display_group )
    background_bitmap = displayio.Bitmap( 128, 128, 1 )
    background_palette = displayio.Palette(1)
    background_palette[0] = 0x888888  # Gray
    background_square = displayio.TileGrid( background_bitmap, pixel_shader=background_palette, x=0, y=0 )
    display_group.append(background_square)

    text = "onboard\nLED"
    text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
    text_group = displayio.Group( scale=2, x=20, y=25 )
    text_group.append( text_area )
    display_group.append( text_group )


    text = "{}".format( loop_count )
    text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
    text_group = displayio.Group( scale=2, x=50, y=90 )
    text_group.append( text_area )
    display_group.append( text_group )

    led_text = "ON"
    led_text_area = label.Label( terminalio.FONT, text=led_text, color=0xFFFFFF )
    led_text_group = displayio.Group( scale=2, x=70, y=55 )
    led_text_group.append( led_text_area )
    display_group.append( led_text_group )

try:
    while True:
        time.sleep( 2 )
        loop_count += 1
        print( "loop count = {}".format( loop_count ))
        if display:
            text_area.text = "{}".format( loop_count )
            led_text_area.text = "ON"
        if onboard_LED:
            onboard_LED.value = True
        print( "LED ON" )
        time.sleep( 2 )
        if onboard_LED:
            onboard_LED.value = False
        if display:
            led_text_area.text = "OFF"
        print( "LED OFF" )
finally:
        displayio.release_displays()
        print( "displayio displays released" )
        i2c_bus.deinit()
        print( "i2c_bus deinitialized" )
        print( " ---- end --- " )





