import time
import board
import neopixel
import displayio
import terminalio
from adafruit_display_text import label
import adafruit_ssd1327

pixel_pin = board.NEOPIXEL
number_of_pixels = 1
ORDER = neopixel.GRB

pixels = neopixel.NeoPixel( pixel_pin, number_of_pixels, brightness=0.2, auto_write=True, pixel_order=ORDER )

displayio.release_displays()

try:
    i2c_bus = board.I2C()
    print( "i2c bus initialized" )
except:
    print( "i2c bus failed to initialize" )
    i2c_bus = False

try:
    display_bus = displayio.I2CDisplay(i2c_bus, device_address=0x3D)
    display = adafruit_ssd1327.SSD1327(display_bus, width=128, height=128)
    print( "display initialized" )
except:
    print( "display failed to initialize" )
    display = False

loop_count = 0

if display:
    display_group = displayio.Group()
    display.show( display_group )
    background_bitmap = displayio.Bitmap( 128, 128, 1 )
    background_palette = displayio.Palette(1)
    background_palette[0] = 0x888888  # Gray
    background_square = displayio.TileGrid( background_bitmap, pixel_shader=background_palette, x=0, y=0 )
    display_group.append(background_square)

    text = "onboard\nNEO"
    text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
    text_group = displayio.Group( scale=2, x=15, y=25 )
    text_group.append( text_area )
    display_group.append( text_group )


    text = "{}".format( loop_count )
    text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
    text_group = displayio.Group( scale=2, x=50, y=90 )
    text_group.append( text_area )
    display_group.append( text_group )

    rgb_text = "RED"
    rgb_text_area = label.Label( terminalio.FONT, text=rgb_text, color=0xFFFFFF )
    rgb_text_group = displayio.Group( scale=2, x=65, y=55 )
    rgb_text_group.append( rgb_text_area )
    display_group.append( rgb_text_group )

try:
    while True:
        print( "loop count {}".format(loop_count))
        pixels.fill((255, 0, 0))
        print( "RED" )
        if display:
            text_area.text = str(loop_count)
            rgb_text_area.text = "RED"
        time.sleep(1)

        pixels.fill((0, 255, 0))
        print( "GREEN" )
        if display:
            rgb_text_area.text = "GREEN"
        time.sleep(1)

        pixels.fill((0, 0, 255))
        print( "BLUE" )
        if display:
            rgb_text_area.text = "BLUE"
        time.sleep(1)

        loop_count += 1

finally:
        displayio.release_displays()
        print( "displayio displays released" )
        i2c_bus.deinit()
        print( "i2c_bus deinitialized" )
        print( " ---- end --- " )

