# STELLA-AQ test code i2c_bus_scan

# STELLA bus addresses
# listing available at https://learn.adafruit.com/i2c-addresses/the-list


# 0x12 -- PM2.5 particulate sensor - PMSA003I
# 0x36 -- MAX1704x battery health monitor
# 0x3d -- 1.5" 128x128 OLED display - ssd1327
# 0x62 -- CO2 sensor - SCD40
# 0x68 -- clock: Real time clock - PCF8523
# 0x77 -- WX barometric pressure, relative humidity, temperature - BME280


# expect i2c addresses found: ['0x12', '0x36','0x3d', '0x62', '0x68', '0x77']

import time
import board
import busio
import displayio
import terminalio
from adafruit_display_text import label
import adafruit_ssd1327

displayio.release_displays()

try:
    i2c_bus = board.I2C()
    print( "i2c bus initialized" )
except:
    print( "i2c bus failed to initialize" )
    i2c_bus = False

if i2c_bus:
    while not i2c_bus.try_lock():
        print( "i2c will not lock" )
        time.sleep(2)

for count in range (0,3):
    devices_present = [hex(device_address) for device_address in i2c_bus.scan()]
    print("i2c addresses found:{}".format( devices_present ))
    time.sleep(1)

i2c_bus.unlock()

display = False
try:
    display_bus = displayio.I2CDisplay(i2c_bus, device_address=0x3D)
    display = adafruit_ssd1327.SSD1327(display_bus, width=128, height=128)
    print( "display initialized" )
except:
    print( "display failed to initialize" )
    display = False

loop_count = 0

try:
    if display:
        display_group = displayio.Group()
        display.show( display_group )
        background_bitmap = displayio.Bitmap( 128, 128, 1 )
        background_palette = displayio.Palette(1)
        background_palette[0] = 0x444444  # Gray
        background_square = displayio.TileGrid( background_bitmap, pixel_shader=background_palette, x=0, y=0 )
        display_group.append(background_square)

        text = "Devices:\nparticulates\nbattery monitor\ndisplay\nCO2\nclock\nweather"
        text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
        text_group = displayio.Group( scale=1, x=35, y=15 )
        text_group.append( text_area )
        display_group.append( text_group )

        text = "i2c"
        text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
        text_group = displayio.Group( scale=1, x=10, y=15 )
        text_group.append( text_area )
        display_group.append( text_group )

        if ('0x12') in devices_present:
            print("pm_2_5 found")
            text = "YES"
        else:
            print("pm_2_5 not found")
            text = "NO"
        text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
        text_group = displayio.Group( scale=1, x=10, y=30 )
        text_group.append( text_area )
        display_group.append( text_group )

        if ('0x36') in devices_present:
            print("battery monitor found")
            text = "YES"
        else:
            print("battery monitor not found")
            text = "NO"
        text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
        text_group = displayio.Group( scale=1, x=10, y=45 )
        text_group.append( text_area )
        display_group.append( text_group )

        if ('0x3d') in devices_present:
            print("display found")
            text = "YES"
        else:
            print("display not found")
            text = "NO"
        text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
        text_group = displayio.Group( scale=1, x=10, y=60 )
        text_group.append( text_area )
        display_group.append( text_group )

        if ('0x62') in devices_present:
            print("CO2 found")
            text = "YES"
        else:
            print("CO2 not found")
            text = "NO"
        text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
        text_group = displayio.Group( scale=1, x=10, y=75 )
        text_group.append( text_area )
        display_group.append( text_group )

        if ('0x68') in devices_present:
            print("clock found")
            text = "YES"
        else:
            print("clock not found")
            text = "NO"
        text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
        text_group = displayio.Group( scale=1, x=10, y=90 )
        text_group.append( text_area )
        display_group.append( text_group )

        if ('0x77') in devices_present:
            print("WX found")
            text = "YES"
        else:
            print("WX not found")
            text = "NO"
        text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
        text_group = displayio.Group( scale=1, x=10, y=105 )
        text_group.append( text_area )
        display_group.append( text_group )









    time.sleep(5)


finally:
        displayio.release_displays()
        print( "displayio displays released" )
        i2c_bus.deinit()
        print( "i2c_bus deinitialized" )
        print( " ---- end --- " )

