import time
import board
import displayio
import terminalio
from adafruit_display_text import label
import adafruit_ssd1327
import adafruit_scd4x

try:
    i2c_bus = board.I2C()
    print( "i2c bus initialized" )
except:
    print( "i2c bus failed to initialize" )
    i2c_bus = False

try:
    display_bus = displayio.I2CDisplay(i2c_bus, device_address=0x3D)
    display = adafruit_ssd1327.SSD1327(display_bus, width=128, height=128)
    print( "display initialized" )
except:
    print( "display failed to initialize" )
    display = False

loop_count = 0

if display:
    display_group = displayio.Group()
    display.show( display_group )
    background_bitmap = displayio.Bitmap( 128, 128, 1 )
    background_palette = displayio.Palette(1)
    background_palette[0] = 0x888888  # Gray
    background_square = displayio.TileGrid( background_bitmap, pixel_shader=background_palette, x=0, y=0 )
    display_group.append(background_square)

    text = "CO2 sensor"
    text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
    text_group = displayio.Group( scale=2, x=5, y=25 )
    text_group.append( text_area )
    display_group.append( text_group )

    text = ""
    text_area = label.Label( terminalio.FONT, text=text, color=0xFFFFFF )
    text_group = displayio.Group( scale=2, x=5, y=50 )
    text_group.append( text_area )
    display_group.append( text_group )

scd4x = adafruit_scd4x.SCD4X(i2c_bus)
print("Serial number:", [hex(i) for i in scd4x.serial_number])

scd4x.start_periodic_measurement()
print("Waiting for first measurement....")
text_area.text = "waiting..."
try:
    while True:
        if scd4x.data_ready:
            co2_ppm = scd4x.CO2
            text_area.text = str(co2_ppm)+" ppm"
            print("CO2: %d ppm" % co2_ppm)
            print("Temperature: %0.1f *C" % scd4x.temperature)
            print("Humidity: %0.1f %%" % scd4x.relative_humidity)
            print()
        time.sleep(0.5)
finally:
        displayio.release_displays()
        print( "displayio displays released" )
        i2c_bus.deinit()
        print( "i2c_bus deinitialized" )
        print( " ---- end --- " )
